# Release information about Tasty

version = "1.3"

description = "rich, general purpose tagging engine built as a REST service"
long_description = "rich, general purpose tagging engine built as a REST service"
author = "Anders Pearson"
email = "anders@columbia.edu"
# copyright = "Vintage 2006 - a good year indeed"

# if it's open source, you might want to specify these
url = "http://code.google.com/p/microapps/wiki/Tasty"
# download_url = "http://yourcool.site/download"
license = "http://www.gnu.org/licenses/gpl.html"
